16.88. cdist-type__motd(7) — cdist 6.5.4 documentation

# 16.88. cdist-type__motd(7)

## 16.88.1. NAME

cdist-type__motd - Manage message of the day

## 16.88.2. DESCRIPTION

This cdist type allows you to easily setup /etc/motd.

## 16.88.3. REQUIRED PARAMETERS

None.

## 16.88.4. OPTIONAL PARAMETERS

source
  If supplied, copy this file from the host running cdist to the target. If not supplied, a default message will be placed onto the target.

## 16.88.5. EXAMPLES

    # Use cdist defaults
    __motd

    # Supply source file from a different type
    __motd --source "$__type/files/my-motd"

## 16.88.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.88.7. COPYING

Copyright (C) 2011 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.